if [ ! -e /etc/xpdfrc ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/xpdfrc /etc/xpdfrc
fi

rm -f /usr/share/icons/hicolor/icon-theme.cache
